abjadbooktools.AbjadBookProcessor
=================================

.. abjad-lineage:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor

.. autoclass:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.directory
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.image_prefix
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.lines
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.output_format
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.skip_rendering
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.update_status
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.verbose
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__call__
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__eq__
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__format__
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__hash__
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__ne__
      ~abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.directory
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.image_prefix
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.lines
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.output_format
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.skip_rendering
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.verbose
   :noindex:

Methods
-------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.update_status
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__call__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__eq__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__format__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__hash__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__ne__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookProcessor.AbjadBookProcessor.__repr__
   :noindex:
